pub struct AttachHooks {
pub probe: ProbeFn,
pub ensure: EnsureFn,
pub connect: ConnectFn,
}Expand description
Hooks so --offline can be tested with a connector that panics.
Fields
probe: ProbeFnWhether socket already accepts connections.
ensure: EnsureFnSpawn serve when the socket is free.
connect: ConnectFnDial the socket after probe or a successful ensure.